Module: Devise::KoalaConnectable::Helpers
- Defined in:
- lib/devise_koala_connectable/view_helpers.rb
Overview
Koala view helpers to easily add the link to the Facebook connection popup and also the necessary JS code.
Instance Method Summary collapse
-
#javascript_include_koala ⇒ Object
Returns the necessary JS code for the Facebook popup.
-
#koala_login_button(button_text = "Login with Facebook", login_url = "/", registration_url = nil) ⇒ Object
Returns the Login To Facebook button.
-
#koala_logout_button(button_text = "Logout", logout_url = "/", options = {}) ⇒ Object
Returns the Logout button for Facebook.
-
#koala_registration_form(registration_url = "/", fields = [:name, :email, :password], on_validate = nil, locale = "en_EN", width = nil) ⇒ Object
Renders the Facbook Registration Form (XFML).
-
#koala_registration_iframe_form(registration_url = "/", fields = [:name, :email, :password], locale = "en_EN", width = "100%", height = 330) ⇒ Object
Renders the Facbook Registration Form (Iframe).
-
#link_to_koala(link_text, link_url, options = {}) ⇒ Object
Creates the link to the Facebook connection popup.
Instance Method Details
#javascript_include_koala ⇒ Object
Returns the necessary JS code for the Facebook popup. It is recommended to put this code just before the